DROP VIEW IF EXISTS auto_change_status_v;

CREATE VIEW auto_change_status_v AS
  SELECT DISTINCT cri.change_request_date,
    acs.unique_business_role_id,
    br.name AS business_role,
    cri.item_type,
    cri.change_request_type AS task,
    su.unique_user_id,
    su.display_name AS username,
    perm.unique_permission_id,
    perm.name AS permission,
    perm.risk AS permission_risk,
    ds.unique_id AS application_id,
    ds.name AS application,
    app1.risk AS application_risk,
    cia.change_item_status AS request_status,
        CASE
            WHEN cia.change_item_status::text = ANY (ARRAY['PENDING'::character varying::text, 'RETRY'::character varying::text, 'ERROR'::character varying::text]) THEN NULL::timestamp with time zone
            ELSE cia.last_updated
        END AS fulfillmenttime,
    cri.fulfiller_type,
    COALESCE(fufusr.display_name, fic.fulfiller_name) AS fulfillerusername,
        CASE
            WHEN cri.fulfiller_type::text = 'GROUP'::text THEN sgrp.name
            WHEN cri.fulfiller_type::text = 'USER'::text THEN susr.display_name
            ELSE NULL::character varying
        END AS assigned_fulfiller
   FROM change_request_item cri
     JOIN auto_change_request acr ON cri.auto_change_request_id = acr.id
     JOIN auto_change_set acs ON acr.auto_change_set_id = acs.id
     JOIN business_role br ON acs.unique_business_role_id::text = br.unique_id::text
     JOIN suser su ON cri.user_uid::text = su.unique_user_id::text AND su.effective = true
     LEFT JOIN spermission perm ON cri.permission::text = perm.unique_permission_id::text AND perm.effective = true
     LEFT JOIN saccount acct ON cri.account::text = acct.unique_account_id::text AND acct.effective = true
     LEFT JOIN data_source ds ON ds.id = cri.application
     LEFT JOIN change_item_action cia ON cia.id = cri.latest_action
     LEFT JOIN suser fufusr ON cia.fulfiller_id::text = fufusr.unique_user_id::text AND fufusr.effective = true
     LEFT JOIN access_request_item ari ON cia.id = ari.id
     LEFT JOIN resource_request_item rri ON ari.unique_item_id::text = rri.unique_item_id::text
     LEFT JOIN fulfillment_item_combined fic ON fic.id = rri.change_request_item_id
     LEFT JOIN resource_request rr ON rr.id = rri.resource_request_id
     LEFT JOIN sgroup sgrp ON sgrp.unique_group_id::text = cri.fulfiller::text AND sgrp.effective = true
     LEFT JOIN suser susr ON susr.unique_user_id::text = cri.fulfiller::text AND susr.effective = true
     LEFT JOIN application app1 ON app1.qid::text = ds.unique_id::text;

ALTER TABLE auto_change_status_v
  OWNER TO igops;
GRANT ALL ON TABLE auto_change_status_v TO igops;
GRANT SELECT ON TABLE auto_change_status_v TO ig_report_role;